@@ -6,15 +6,14 @@
 #' Files do not have column headers hence function will take care to name columns as well as to perform relevant cleansing
 #'
 #'
-#' @param path_terminal - path of the Trading Terminal where the file with data is written
-#' @param trade_log_file - File name where the order results are written
-#' @param demo_mode - When true function uses data stored in the package data folder
+#' @param path_sbxm - String, Path to the sandbox with the log file where the file with data is written
+#' @param trade_log_file - String, File name where the order results are written
 #'
 #'
 #' @return Function will return the dataframe with trade data and automatically set proper column types
 #' @export
 #'
-#' @author (C) 2019 Vladimir Zhbanko
+#' @author (C) 2019, 2020 Vladimir Zhbanko
 #'
 #' @examples
 #'
@@ -22,37 +21,29 @@
 #' library(dplyr)
 #' library(readr)
 #' library(lubridate)
-#' DFT1 <- import_data(trade_log_file = system.file("extdata",
-#'                                                  "OrdersResultsT1.csv",
-#'                                                  package = "lazytrade"),
-#'                     demo_mode = TRUE)
+#'
+#' path_sbxm <- normalizePath(tempdir(),winslash = "/")
+#'
+#' file.copy(from = system.file("extdata", "OrdersResultsT1.csv", package = "lazytrade"),
+#'           to = file.path(path_sbxm, "OrdersResultsT1.csv"), overwrite = TRUE)
+#'
+#' DFT1 <- import_data(path_sbxm = path_sbxm,
+#'                     trade_log_file = "OrdersResultsT1.csv")
 #'
 #'
 #'
-import_data <- function(path_terminal, trade_log_file, demo_mode = FALSE){
+import_data <- function(path_sbxm, trade_log_file){
   requireNamespace("readr", quietly = TRUE)
   requireNamespace("dplyr", quietly = TRUE)
   requireNamespace("lubridate", quietly = TRUE)
 
-  # use in production to read file
-  if(!demo_mode){
 
-  DFT1 <- try(read_csv(file = file.path(path_terminal, trade_log_file),
+  DFT1 <- try(read_csv(file = file.path(path_sbxm, trade_log_file),
                        col_names = c("MagicNumber", "TicketNumber", "OrderStartTime",
                                      "OrderCloseTime", "Profit", "Symbol", "OrderType"),
                        col_types = "iiccdci"),
               silent = TRUE)
 
-  # this is used for demo only
-  } else {
-
-
-    DFT1 <- try(read_csv(file = trade_log_file,
-                         col_names = c("MagicNumber", "TicketNumber", "OrderStartTime",
-                                       "OrderCloseTime", "Profit", "Symbol", "OrderType"),
-                         col_types = "iiccdci"),
-                silent = TRUE)
-  }
 
   # evaluate content of the table, stop function if there was an error to read file
   if(class(DFT1)[1] == "try-error") {stop("Error reading file. File with trades may not exist yet!",
