@@ -18,10 +18,12 @@
         "X2", "X20", "X21", "X22", "X23", "X24", "X25", "X26", "X27", "X28", "X29",
         "X3", "X4", "X5", "X6", "X7", "X8", "X9", "alpha", "any_vars",
         "computePolicy", "decrypt_envelope", "epsilon",
-        "funs", "n", "nOrders",  "path_T1", "path_T3",
+        "funs", "n", "nOrders",  "path_T1", "path_T3","path_model", "path_data",
         "rewardseq.OFF", "rewardseq.ON",
         "totreward", "trstate", "MarketType","predict_CMSUM", "LABEL_CMSUM",
-        "CUMSUM_PNL", "DFR", "PairGain", "Symbol", "aes",
+        "CUMSUM_PNL", "DFR", "PairGain", "Symbol", "aes", "asset_name",
+
+        "Hold_NB", "MaxPerf", "NB_hold", "PnL_NB", "TR_Level", "X2_NB",
 
 
         # sample function names
@@ -33,7 +35,7 @@
         "predict", "read_rds", "summarise", "write.csv", "write_rds", "ymd_hms",
         "filter_all", "full_join", "bind_rows",  "as.h2o", "bind_cols", "testdir",
         "h2o.performance", "distinct", "dev.off", "geom_bar", "geom_line", "ggplot", "ggtitle", "pdf",
-        "sha512", "write_tsv", "encrypt_envelope", "mutate_at"
+        "sha512", "write_tsv", "encrypt_envelope", "mutate_at", "across"
       )
     )
 
